@@ -44,6 +44,7 @@
 #include <QDesktopServices>
 #include <KMessageBox>
 #include <KLocalizedString>
+#include <KEmailAddress>
 
 #include <QTextStream>
 #include <QWidget>
@@ -145,3 +146,20 @@ void PimCommon::Util::invokeHelp(const QString &docfile, const QString &anchor)
         QDesktopServices::openUrl(url);
     }
 }
+
+QStringList PimCommon::Util::generateEmailList(const QStringList &list)
+{
+    QString str;
+    const int numberOfElement{list.count()};
+    for (int i = 0; i < numberOfElement; i++) {
+        QString tmpStr = list.at(i);
+        if (!tmpStr.trimmed().isEmpty()) {
+            if (!str.isEmpty()) {
+                str.append(QStringLiteral(", "));
+            }
+            str.append(tmpStr);
+        }
+    }
+    const QStringList emails = KEmailAddress::splitAddressList(str);
+    return emails;
+}
