@@ -4,7 +4,7 @@
     This file is part of KMail, the KDE mail client.
     Copyright (c) 2001 Marc Mutz <mutz@kde.org>
 
-    Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+    Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
     KMail is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License, version 2, as
@@ -87,7 +87,7 @@ public:
     void setButtonText(ButtonCode button, const QString &text);
 
     void setUpDownAutoRepeat(bool b);
-    QSize sizeHint() const Q_DECL_OVERRIDE;
+    QSize sizeHint() const override;
 
     virtual void addNewEntry();
     virtual QString modifyEntry(const QString &text);
