@@ -55,7 +55,7 @@ public:
     }
 
 protected:
-    void actionEvent(QActionEvent *event) Q_DECL_OVERRIDE {
+    void actionEvent(QActionEvent *event) override {
         QAction *action = event->action();
         switch (event->type())
         {
